@@ -80,8 +80,7 @@ _LOGGER = logging.getLogger(__name__)
 class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
     """Tasmota light configuation."""
 
-    dimmer_cmd: str = attr.ib()
-    dimmer_state: str = attr.ib()
+    dimmer: str = attr.ib()
     command_topic: str = attr.ib()
     control_by_channel: bool = attr.ib()
     light_type: int = attr.ib()
@@ -98,18 +97,17 @@ class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
     @classmethod
     def from_discovery_message(cls, config, idx, platform):
         """Instantiate from discovery message."""
-        dimmer_cmd = COMMAND_DIMMER
-        dimmer_state = COMMAND_DIMMER
+        dimmer = COMMAND_DIMMER
         control_by_channel = False  # Use Channel<n> command to control the light
         if config[CONF_TUYA]:
             dimmer_idx = 3  # Brightness controlled by DIMMER3
-            dimmer_cmd = f"{COMMAND_DIMMER}{dimmer_idx}"
+            dimmer = f"{COMMAND_DIMMER}{dimmer_idx}"
         tasmota_light_sub_type = config[CONF_LIGHT_SUBTYPE]
         light_type = LIGHT_TYPE_MAP[tasmota_light_sub_type]
 
         if config[CONF_OPTIONS][OPTION_PWM_MULTI_CHANNELS]:
             # Multi-channel PWM instead of a single light, each light controlled by CHANNEL<n>
-            dimmer_state = f"{COMMAND_CHANNEL}{idx+1}"
+            dimmer = f"{COMMAND_CHANNEL}{idx+1}"
             control_by_channel = True
             light_type = LIGHT_TYPE_DIMMER
         elif not config[CONF_LINK_RGB_CT] and tasmota_light_sub_type >= LST_RGBW:
@@ -124,8 +122,7 @@ class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
                     light_type = LIGHT_TYPE_DIMMER
                 else:
                     light_type = LIGHT_TYPE_COLDWARM
-            dimmer_cmd = f"{COMMAND_DIMMER}{dimmer_idx}"
-            dimmer_state = f"{COMMAND_DIMMER}{dimmer_idx}"
+            dimmer = f"{COMMAND_DIMMER}{dimmer_idx}"
 
         min_mireds = DEFAULT_MIN_MIREDS
         max_mireds = DEFAULT_MAX_MIREDS
@@ -144,8 +141,7 @@ class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
             availability_topic=get_topic_tele_will(config),
             availability_offline=config_get_state_offline(config),
             availability_online=config_get_state_online(config),
-            dimmer_cmd=dimmer_cmd,
-            dimmer_state=dimmer_state,
+            dimmer=dimmer,
             command_topic=get_topic_command(config),
             control_by_channel=control_by_channel,
             light_type=light_type,
@@ -183,22 +179,14 @@ class TasmotaLight(TasmotaAvailability, TasmotaEntity):
             if self._cfg.endpoint == "light":
                 if self._cfg.light_type != LIGHT_TYPE_NONE:
 
-                    brightness = get_value_by_path(
-                        msg.payload, [self._cfg.dimmer_state]
-                    )
+                    brightness = get_value_by_path(msg.payload, [self._cfg.dimmer])
                     if brightness is not None:
                         self._brightness = brightness
                         attributes["brightness"] = brightness
 
                     color = get_value_by_path(msg.payload, [COMMAND_COLOR])
                     if color is not None:
-                        if color.find(",") != -1:
-                            color = color.split(",", 3)
-                        else:
-                            color = [
-                                int(color[i : i + 2], 16)
-                                for i in range(0, len(color), 2)
-                            ]
+                        color = color.split(",", 3)
                         if len(color) >= 3:
                             color = [float(color[0]), float(color[1]), float(color[2])]
                             self._color = color
@@ -352,10 +340,7 @@ class TasmotaLight(TasmotaAvailability, TasmotaEntity):
             delta_ratio = max(
                 map(abs, [x1 - x2 for (x1, x2) in zip(now_channels, new_channels)])
             )
-            if delta_ratio == 0:
-                speed = 0
-            else:
-                speed = round(transition * 2 / delta_ratio)
+            speed = round(transition * 2 / delta_ratio)
             # Clamp speed to the range 1..40
             speed = min(max(speed, 1), 40)
             command = COMMAND_SPEED
@@ -368,7 +353,7 @@ class TasmotaLight(TasmotaAvailability, TasmotaEntity):
             if self._cfg.control_by_channel:
                 command = f"{COMMAND_CHANNEL}{idx+1}"
             else:
-                command = self._cfg.dimmer_cmd
+                command = self._cfg.dimmer
 
         commands.append((command, argument))
 
